==> 0.0.2.tar.gz: lib/flutter_carousel_media_slider.dart <==
library flutter_carousel_media_slider;

import 'dart:async';

import 'package:flutter/material.dart';
import 'package:flutter_carousel_media_slider/src/carousel_helper.dart';
import 'package:flutter_carousel_media_slider/carousel_media.dart';
import 'package:flutter_carousel_media_slider/src/image_helper.dart';
import 'package:flutter_carousel_media_slider/src/utils.dart';
import 'package:flutter_carousel_media_slider/src/video_player_helper.dart';

class FlutterCarouselMediaSlider extends StatefulWidget {
  const FlutterCarouselMediaSlider({
    Key? key,
    this.placeholderImage,
    this.carouselDuration,
    this.carouselOptions,
    required this.carouselMediaList,
    this.boxFit,
    this.height,
    this.autoPlayAnimationDuration,
    required this.onPageChanged,
  }) : super(key: key);

  /// Placeholder for the carousel image while images are loading from network.
  /// Default value is CircularProgressIndicator().
  final String? placeholderImage;

  /// List of media files to be displayed in the carousel.
  final List<CarouselMedia> carouselMediaList;

  /// Duration of the carousel animation.
  /// This will apply only to the images only.
  /// For videos, this is the duration of the video.
  /// Default is [Duration(seconds: 10)].
  final Duration? carouselDuration;

  /// Time between carousel animation transition.
  /// This will apply only to the images only.
  /// For videos, this is the duration of the video.
  /// Default is [Duration(milliseconds: 200)].
  final Duration? autoPlayAnimationDuration;

  /// Set this to true, if you want to show all the images in the
  /// carousel first followed by all video files in next.
  final bool showImagesFirst = true;

  /// [CarouselOptions] to create a [CarouselState] with
  final CarouselOptions? carouselOptions;

  /// Box Fit for the images in the carousel.
  /// Default is [BoxFit.cover].
  final BoxFit? boxFit;

  /// Height of the carousel.
  /// Default is [double.infinity].
  final double? height;

  final Function onPageChanged;

  @override
  State<FlutterCarouselMediaSlider> createState() =>
      _FlutterCarouselMediaSliderState();
}

class _FlutterCarouselMediaSliderState
    extends State<FlutterCarouselMediaSlider> {
  final CarouselController controller = CarouselController();

  @override
  void initState() {
    super.initState();

    widget.carouselMediaList.sort((a, b) {
      if (a.mediaType == CarouselMediaType.image &&
          b.mediaType == CarouselMediaType.video) {
        return -1;
      } else if (a.mediaType == CarouselMediaType.video &&
          b.mediaType == CarouselMediaType.image) {
        return 1;
      } else {
        return 0;
      }
    });

    if (!widget.showImagesFirst) {
      widget.carouselMediaList.reversed;
    }
  }

  @override
  Widget build(BuildContext context) {
    return CarouselHelper.builder(
      options: CarouselOptions(
        initialPage: 0,
        autoPlayAnimationDuration: widget.autoPlayAnimationDuration ??
            const Duration(milliseconds: 200),
        viewportFraction: 1,
        enlargeCenterPage: true,
        enableInfiniteScroll: true,
        height: widget.height ?? double.infinity,
        onPageChanged: (int index, CarouselPageChangedReason reason) async {
          widget.onPageChanged(index);
          if (widget.carouselMediaList[index].mediaType ==
              CarouselMediaType.image) {
            loadNextPage(index);
          }
        },
      ),
      onPageLoaded: () async {
        loadNextPage(0);
      },
      carouselController: controller,
      itemCount: widget.carouselMediaList.length,
      itemBuilder: (BuildContext context, int index, int realIndex) {
        final CarouselMedia carouselMedia = widget.carouselMediaList[index];
        if (carouselMedia.mediaType == CarouselMediaType.video) {
          return VideoPlayerHelper(
            carouselMedia: carouselMedia,
            onComplete: () {
              controller.animateToPage(index + 1);
            },
            placeholder: loadPlaceholder(
              widget.placeholderImage,
            ),
          );
        }
        return ImageHelper(
          carouselMedia: carouselMedia,
          boxFit: widget.boxFit ?? BoxFit.cover,
          placeholderImage: widget.placeholderImage,
        );
      },
    );
  }

  Future<void> loadNextPage(int index) async {
    await Future.delayed(
        widget.carouselDuration ?? const Duration(seconds: 10));
    controller.animateToPage(index + 1);
  }
}

==> 0.0.4.tar.gz: lib/flutter_carousel_media_slider.dart <==
library flutter_carousel_media_slider;

import 'dart:async';

import 'package:flutter/material.dart';
import 'package:flutter_carousel_media_slider/carousel_media.dart';
import 'package:flutter_carousel_media_slider/src/carousel_helper.dart';
import 'package:flutter_carousel_media_slider/src/image_helper.dart';
import 'package:flutter_carousel_media_slider/src/utils.dart';
import 'package:flutter_carousel_media_slider/src/video_player_helper.dart';
import 'package:flutter_carousel_media_slider/src/youtube_player_helper.dart';

class FlutterCarouselMediaSlider extends StatefulWidget {
  const FlutterCarouselMediaSlider({
    Key? key,
    this.placeholder,
    this.carouselDuration,
    required this.carouselMediaList,
    this.boxFit,
    this.height,
    this.autoPlayAnimationDuration,
    required this.onPageChanged,
  }) : super(key: key);

  /// Placeholder for the carousel image while images are loading from network.
  /// Default value is CircularProgressIndicator().
  final Widget? placeholder;

  /// List of media files to be displayed in the carousel.
  final List<CarouselMedia> carouselMediaList;

  /// Duration of the carousel animation.
  /// This will apply only to the images only.
  /// For videos, this is the duration of the video.
  /// Default is [Duration(seconds: 10)].
  final Duration? carouselDuration;

  /// Time between carousel animation transition.
  /// This will apply only to the images only.
  /// For videos, this is the duration of the video.
  /// Default is [Duration(milliseconds: 200)].
  final Duration? autoPlayAnimationDuration;

  /// Set this to true, if you want to show all the images in the
  /// carousel first followed by all video files in next.
  final bool showImagesFirst = true;

  /// Box Fit for the images in the carousel.
  /// Default is [BoxFit.cover].
  final BoxFit? boxFit;

  /// Height of the carousel.
  /// Default is [double.infinity].
  final double? height;

  final Function onPageChanged;

  @override
  State<FlutterCarouselMediaSlider> createState() =>
      _FlutterCarouselMediaSliderState();
}

class _FlutterCarouselMediaSliderState
    extends State<FlutterCarouselMediaSlider> {
  final CarouselController controller = CarouselController();

  @override
  void initState() {
    super.initState();

    widget.carouselMediaList.removeWhere(
        (element) => (element.mediaUrl?.startsWith('http://') == true));

    if (!widget.showImagesFirst) {
      widget.carouselMediaList.sort((a, b) {
        if (a.mediaType == CarouselMediaType.image &&
            b.mediaType == CarouselMediaType.video) {
          return -1;
        } else if (a.mediaType == CarouselMediaType.video &&
            b.mediaType == CarouselMediaType.image) {
          return 1;
        } else {
          return 0;
        }
      });
      widget.carouselMediaList.reversed;
    }
    debugPrint('Carousel Media List: ${widget.carouselMediaList.length}');
  }

  @override
  Widget build(BuildContext context) {
    return CarouselHelper.builder(
      options: CarouselOptions(
        initialPage: 0,
        autoPlayAnimationDuration: widget.autoPlayAnimationDuration ??
            const Duration(milliseconds: 200),
        viewportFraction: 1,
        enlargeCenterPage: true,
        enableInfiniteScroll: (widget.carouselMediaList.length > 1),
        autoPlay: (widget.carouselMediaList.length > 1),
        height: widget.height ?? double.infinity,
        onPageChanged: (int index, CarouselPageChangedReason reason) async {
          widget.onPageChanged(index);
          if (widget.carouselMediaList[index].mediaType ==
              CarouselMediaType.image) {
            loadNextPage(index);
          }
        },
      ),
      onPageLoaded: () async {
        loadNextPage(0);
      },
      carouselController: controller,
      itemCount: widget.carouselMediaList.length,
      itemBuilder: (BuildContext context, int index, int realIndex) {
        final CarouselMedia carouselMedia = widget.carouselMediaList[index];
        if (carouselMedia.mediaType == CarouselMediaType.video) {
          if ((Uri.tryParse(carouselMedia.mediaUrl ?? '')?.host ?? '')
              .contains('youtube')) {
            return YoutubePlayerHelper(
              url: carouselMedia.mediaUrl ?? '',
              onComplete: () {
                controller.animateToPage(index + 1);
              },
              onError: (error) {
                handleError(index);
              },
              isLooping: !(widget.carouselMediaList.length > 1),
            );
          } else {
            return VideoPlayerHelper(
              carouselMedia: carouselMedia,
              onComplete: () {
                controller.animateToPage(index + 1);
              },
              placeholder: loadPlaceholder(
                widget.placeholder,
              ),
              onError: (error) {
                handleError(index);
              },
              isLooping: !(widget.carouselMediaList.length > 1),
            );
          }
        }
        return ImageHelper(
          carouselMedia: carouselMedia,
          boxFit: widget.boxFit ?? BoxFit.cover,
          placeholderImage: widget.placeholder,
          onError: (error) {
            handleError(index);
          },
        );
      },
    );
  }

  void handleError(int index) {
    try {
      widget.carouselMediaList.removeAt(index);
      setState(() {});
    } catch (e) {
      debugPrint('Error: $e');
    }
  }

  Future<void> loadNextPage(int index) async {
    if (widget.carouselMediaList[index].mediaType == CarouselMediaType.video) {
      return;
    }
    await Future.delayed(
        widget.carouselDuration ?? const Duration(seconds: 10));
    controller.animateToPage(index + 1);
  }
}
